/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : main.c
* Author             : MCD Application Team
* Version            : V1.0
* Date               : 12/28/2007
* Description        : Power Consumption Demo main file
********************************************************************************
* History:
* 12/28/2007 : Version 1.0
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x_lib.h"
#include "main.h"
#include "power.h"
#include "menu.h"
#include "common.h"

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define Config_HSE_PLL72                    0x1
#define Config_HSI_8                        0x2
#define Config_Sleep_Peripherals            0x20
#define Config_Sleep_without_Peripherals    0x21
#define Config_Stop_Normal                  0x40
#define Config_Stop_LowPower                0x41
#define Config_Standby_RTC                  0x80
#define Config_Standby_NoRTC                0x81

/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* External variables --------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Extern function prototypes ------------------------------------------------*/
/* Private functions ---------------------------------------------------------*/
static void RCC_FirstConfiguration(void);
static void GPIO_FirstConfiguration(void);
static void NVIC_FirstConfiguration(void);
static void GPIO_AllAinConfig(void);
static void Unconfigure_All(void);

/*******************************************************************************
* Function Name  : main
* Description    : main program.
* Input          : None.
* Return         : None.
*******************************************************************************/
int main(void)
{
  u32 i;
  GPIO_InitTypeDef GPIO_InitStructure;
  USART_InitTypeDef USART_InitStructure;

  #ifdef DEBUG
  debug();
  #endif

  // First configuration :
  // RCC in reset configuration run on HSI
  // GPIOC (Leds) & GPIOD (key button) clock enabled
  // LEDs and Key GPIO configured
  // NVIC in reset configuration
  
  RCC_FirstConfiguration();
  GPIO_FirstConfiguration();
  NVIC_FirstConfiguration();

  // Enable backup registers 
  PWR_BackupAccessCmd(ENABLE);

  // LED OFF
  GPIO_ResetBits(GPIOC, GPIO_Pin_7);

 // Check if Key2 is pressed
  if(GPIO_ReadInputDataBit(GPIOD, GPIO_Pin_3)== SET)
  {// keys are not pressed enter configuration based on Backup Register data
    
    // check if backup data are set by a previous configuration or not
    if(BKP_ReadBackupRegister(BKP_DR1) == 0x00)
    {// Backup registers empty
     // LED blink to indicate error
      while(1)
      {
        for (i=0; i<0xffff;i++);
            GPIO_ResetBits(GPIOC, GPIO_Pin_7);
        for (i=0; i<0xffff;i++);
            GPIO_SetBits(GPIOC, GPIO_Pin_7);
      };
    }
    else
    {// Backup registers not empty
     // enter the configured state
      i = BKP_ReadBackupRegister(BKP_DR1);
      Unconfigure_All();
      
      switch (i)
      {
      case Config_HSE_PLL72                    :
        Enter_HSE_PLL72 ();
        break;
        
      case Config_HSI_8                        :
        Enter_HSI_8();
        break;
      
      case Config_Sleep_Peripherals            :
        Enter_Sleep_Peripherals();
        break;
      
      case Config_Sleep_without_Peripherals    :
        Enter_Sleep_without_Peripherals();
        break;
      
      case Config_Stop_Normal                  :
        Enter_Stop_Normal();
        break;
      
      case Config_Stop_LowPower                :
        Enter_Stop_LowPower();
        break;
      
      case Config_Standby_RTC                  :
        Enter_Standby_RTC();
        break;
      
      case Config_Standby_NoRTC                :
        Enter_Standby_NoRTC();
        break;
      
      default:
        while(1)
        {
          for (i=0; i<0x7ffff;i++);
            GPIO_SetBits(GPIOC, GPIO_Pin_7);
          for (i=0; i<0x7ffff;i++);
            GPIO_ResetBits(GPIOC, GPIO_Pin_7);
        };
      }
      while(1);
    }
  }
    /* Enable USART1, GPIOA, GPIOD and AFIO clocks */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_USART1 | RCC_APB2Periph_GPIOA 
                         |RCC_APB2Periph_GPIOC |RCC_APB2Periph_GPIOD, ENABLE);
  
  GPIO_SetBits(GPIOC, GPIO_Pin_7);
  
  /* Configure USART1 Tx (PA.09) as alternate function push-pull */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_9;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
  GPIO_Init(GPIOA, &GPIO_InitStructure);
  
  /* Configure USART1 Rx (PA.10) as input floating */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_10;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN_FLOATING;
  GPIO_Init(GPIOA, &GPIO_InitStructure);
  
  
  USART_InitStructure.USART_BaudRate = 9600;
  USART_InitStructure.USART_WordLength = USART_WordLength_8b;
  USART_InitStructure.USART_StopBits = USART_StopBits_1;
  USART_InitStructure.USART_Parity = USART_Parity_No;
  USART_InitStructure.USART_HardwareFlowControl = USART_HardwareFlowControl_None;
  USART_InitStructure.USART_Mode = USART_Mode_Rx | USART_Mode_Tx;
  USART_InitStructure.USART_Clock = USART_Clock_Disable;
  USART_InitStructure.USART_CPOL = USART_CPOL_Low;
  USART_InitStructure.USART_CPHA = USART_CPHA_2Edge;
  USART_InitStructure.USART_LastBit = USART_LastBit_Disable;
  
  /* Configure USART1 */
  USART_Init(USART1, &USART_InitStructure);

  /* Enable the USART1 */
  USART_Cmd(USART1, ENABLE);

  // wait for 1 key of the hyperterminal to be pressed
  GetKey();

  Menu_Init();
  DisplayMenu();
  
  while(1)
  {
    ManageMenu();
  }

}

/*******************************************************************************
* Function Name  : RCC_FirstConfiguration
* Description    : initial clock configuration
* Input          : None.
* Return         : None.
*******************************************************************************/
void RCC_FirstConfiguration(void)
{
  /* RCC system reset(for debug purpose) */
  RCC_DeInit();

  /* Enable PWR clock */
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_PWR|RCC_APB1Periph_BKP, ENABLE);

  /* Enable GPIOA, GPIOB, GPIOC, GPIOD, GPIOE and AFIO clocks */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOC |RCC_APB2Periph_GPIOD, ENABLE);

}


/*******************************************************************************
* Function Name  : GPIO_FirstConfiguration
* Description    : initial configuration the different GPIO ports.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void GPIO_FirstConfiguration(void)
{
  GPIO_InitTypeDef GPIO_InitStructure;

  /* Input Key configuration */
  /* Configure PD.03 as input floating */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_3;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IN_FLOATING;
  GPIO_Init(GPIOD, &GPIO_InitStructure);

  /* LED configuration */
  /* Configure PC.07 as output push-pull */
  GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_7;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOC, &GPIO_InitStructure);
}

/*******************************************************************************
* Function Name  : NVIC_FirstConfiguration
* Description    : initial Configuration of the NVIC and Vector Table base address.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void NVIC_FirstConfiguration(void)
{
#ifdef  VECT_TAB_RAM
  /* Set the Vector Table base location at 0x20000000 */
  NVIC_SetVectorTable(NVIC_VectTab_RAM, 0x0);
#else  /* VECT_TAB_FLASH  */
  /* Set the Vector Table base location at 0x08000000 */
  NVIC_SetVectorTable(NVIC_VectTab_FLASH, 0x0);
#endif

}


/*******************************************************************************
* Function Name  : Set_xxx
* Description    : Functions that initialise the backup register to enter
*                  a specific mode after a software reset.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void Set_HSE_PLL72 (void)
{
  BKP_WriteBackupRegister(BKP_DR1,0x1); 
  SerialPutString("\r\n The configuration will be effective after reset",51);
  SerialPutString("\r\n Press any key to reset the board",35);
  GetKey();
  NVIC_GenerateSystemReset();
}

void Set_HSI_8(void)
{
  BKP_WriteBackupRegister(BKP_DR1,0x2);
  SerialPutString("\r\n The configuration will be effective after reset",51);
  SerialPutString("\r\n Press any key to reset the board",35);
  GetKey();
  NVIC_GenerateSystemReset();
}

void Set_Sleep_Peripherals(void)
{
  BKP_WriteBackupRegister(BKP_DR1,0x20);
  SerialPutString("\r\n The configuration will be effective after reset",51);
  SerialPutString("\r\n Press any key to reset the board",35);
  GetKey();
  NVIC_GenerateSystemReset();
}

void Set_Sleep_without_Peripherals(void)
{
  BKP_WriteBackupRegister(BKP_DR1,0x21);
  SerialPutString("\r\n The configuration will be effective after reset",51);
  SerialPutString("\r\n Press any key to reset the board",35);
  GetKey();
  NVIC_GenerateSystemReset();
}
void Set_Stop_Normal(void)
{
  BKP_WriteBackupRegister(BKP_DR1,0x40);
  SerialPutString("\r\n The configuration will be effective after reset",51);
  SerialPutString("\r\n Press any key to reset the board",35);
  GetKey();
  NVIC_GenerateSystemReset();
}
void Set_Stop_LowPower(void)
{
  BKP_WriteBackupRegister(BKP_DR1,0x41);
  SerialPutString("\r\n The configuration will be effective after reset",51);
  SerialPutString("\r\n Press any key to reset the board",35);
  GetKey();
  NVIC_GenerateSystemReset();
}
void Set_Standby_RTC(void)
{
  BKP_WriteBackupRegister(BKP_DR1,0x80);
  SerialPutString("\r\n The configuration will be effective after reset",51);
  SerialPutString("\r\n Press any key to reset the board",35);
  GetKey();
  NVIC_GenerateSystemReset();
}
void Set_Standby_NoRTC(void)
{
  BKP_WriteBackupRegister(BKP_DR1,0x81);
  SerialPutString("\r\n The configuration will be effective after reset",51);
  SerialPutString("\r\n Press any key to reset the board",35);
  GetKey();
  NVIC_GenerateSystemReset();
}



/*******************************************************************************
* Function Name  : GPIO_AllAinConfig
* Description    : Configure all GPIO port pins in Analog Input mode 
*                  (floating input trigger OFF)
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void GPIO_AllAinConfig(void)
{
GPIO_InitTypeDef GPIO_InitStructure;

  /* Configure all GPIO port pins in Analog Input mode (floating input trigger OFF) */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_All;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AIN;
//  GPIO_Init(GPIOA, &GPIO_InitStructure);
//  GPIO_Init(GPIOB, &GPIO_InitStructure);
  GPIO_Init(GPIOC, &GPIO_InitStructure);
  GPIO_Init(GPIOD, &GPIO_InitStructure);
//  GPIO_Init(GPIOE, &GPIO_InitStructure);
}

/*******************************************************************************
* Function Name  : Unconfigure_All
* Description    : set all the RCC data to the default values 
*                  configure all the GPIO as input
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void Unconfigure_All(void)
{
  RCC_DeInit();

  /* RCC configuration */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_ALL, DISABLE);
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_ALL, DISABLE);

  GPIO_AllAinConfig();
}


/*******************************************************************************
* Function Name  : ReadConfiguration
* Description    : Read the Backup register and display the selected configuration
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void ReadConfiguration(void)
{
  switch (BKP_ReadBackupRegister(BKP_DR1))
  {
  case Config_HSE_PLL72                    :
    SerialPutString("\r\n HSE PLL 72Mhz",16);
    break;
    
  case Config_HSI_8                        :
    SerialPutString("\r\n HSI 8Mhz",11);
    break;
  
  case Config_Sleep_Peripherals            :
    SerialPutString("\r\n Sleep Mode with all peripherals clocks enabled",49);
    break;
  
  case Config_Sleep_without_Peripherals    :
    SerialPutString("\r\n Sleep Mode with all peripherals clocks disabled",50);
    break;
  
  case Config_Stop_Normal                  :
    SerialPutString("\r\n Stop mode with power regulator in normal mode",48);
    break;
  
  case Config_Stop_LowPower                :
    SerialPutString("\r\n Stop mode with power regulator in low power mode",51);
    break;
  
  case Config_Standby_RTC                  :
    SerialPutString("\r\n Standby mode with RTC enabled",32);
    break;
  
  case Config_Standby_NoRTC                :
    SerialPutString("\r\n Standby mode with RTC disabled",33);
    break;
  
  default:
    SerialPutString("\r\n No mode selected",19);
  }
  
 SerialPutString("\r\n press any key ",17);
 SerialPutString("\r\n",2);
 // wait for 1 key to be pressed
 GetKey();

}


/******************* (C) COPYRIGHT 2007 STMicroelectronics *****END OF FILE****/

