/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : menu.c
* Author             : MCD Application Team
* Date First Issued  : 12/28/2006 : Version 1.0
* Description        : This file includes the UART menu navigation driver.
********************************************************************************
* History:
* 12/28/2007 : Version 1.0
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x_lib.h"
#include "main.h"
#include "menu.h"
#include "common.h"

/* Private typedef -----------------------------------------------------------*/
  typedef void (* tMenuFunc)(void);
  typedef struct sMenuItem * tMenuItem;
  typedef struct sMenu * tMenu;

  struct sMenuItem
  {
    u8* pszTitle;
    u32 titleSize;
    tMenuFunc pfMenuFunc;
    tMenu psSubMenu ;
  } ;

  struct sMenu
  {
    u8* pszTitle;
    u32 titleSize;
    tMenuItem psItems;
    u8 nItems;
  } ;

/* Private define ------------------------------------------------------------*/
#define NULL 0
/* Private macro -------------------------------------------------------------*/
/* Private functions ---------------------------------------------------------*/
static void SelItem(s32 ItemNb);
static void ReturnPreviousMenu(void);

  /* Private variables ---------------------------------------------------------*/

  
  u8 nMenuLevel = 0;

  tMenu psPrevMenu[MAX_MENU_LEVELS];
  tMenu psCurrentMenu;


/*------------------------------ Menu level 3 -------------------------------*/
struct sMenuItem RunSelectItems[] = { {" Run HSE PLL 72Mhz ", 19, Set_HSE_PLL72, NULL},
                                    {" Run HSI 8Mhz ", 14, Set_HSI_8, NULL}};
struct sMenu RunSelect = {"\r\n             Run Mode Configuration            ",48, RunSelectItems, countof(RunSelectItems)};

struct sMenuItem SleepSelectItems[] = { {" Sleep with Peripherals ", 24,Set_Sleep_Peripherals, NULL},
                                      {" Sleep Without Peripherals ", 27, Set_Sleep_without_Peripherals, NULL}};
struct sMenu SleepSelect = {"\r\n            Sleep Mode Configuration           ",48, SleepSelectItems, countof(SleepSelectItems)};

struct sMenuItem StopSelectItems[] = { {" Stop Power Regulator in normal mode ", 37,Set_Stop_Normal, NULL},
                                     {" Stop Power Regulator in low power mode ", 40, Set_Stop_LowPower, NULL}};
struct sMenu StopSelect = {"\r\n            Stop Mode Configuration            ",48, StopSelectItems, countof(StopSelectItems)};

struct sMenuItem StandbySelectItems[] = { {" Standby Mode with RTC ", 23,Set_Standby_RTC, NULL},
                                        {" Standby Mode without RTC ", 26, Set_Standby_NoRTC, NULL}};
struct sMenu StandbySelect = {"\r\n          Standby Mode Configuration           ",48, StandbySelectItems, countof(StandbySelectItems)};

/*------------------------------ Menu level 2 -------------------------------*/
struct sMenuItem ModeSelectItems[] = { {" Run Mode ", 10, IdleFunc, &RunSelect},
                             {" Sleep Mode", 11, IdleFunc, &SleepSelect},
                             {" Stop Mode ",11,  IdleFunc, &StopSelect},
                             {" Standby Mode ",14, IdleFunc, &StandbySelect}};
struct sMenu ModeSelect = {"\r\n              Select Configuration             ",48, ModeSelectItems, countof(ModeSelectItems)};


/*------------------------------ Menu level 1 -------------------------------*/
struct sMenuItem MainMenuItems[] = {
  {" Select Configuration ",22, IdleFunc, &ModeSelect},
  {" Read Configuration ", 20, ReadConfiguration, NULL}};
struct sMenu MainMenu   = {"\r\n                   Main Menu                  ",48,MainMenuItems, countof(MainMenuItems)};

/* Private function prototypes -----------------------------------------------*/

/*******************************************************************************
* Function Name  : Menu_Init
* Description    : Initializes the navigation menu.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void Menu_Init(void)
{
  psCurrentMenu = &MainMenu;
  psPrevMenu[nMenuLevel] = psCurrentMenu;
}

/*******************************************************************************
* Function Name  : DisplayMenu
* Description    : Displays the current menu.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void DisplayMenu(void)
{
  u8 IntegerStr[10];
  u32 i; 
  
  SerialPutString("\r\n==============================================",48 );
  SerialPutString("\r\n                                              ",48);
  SerialPutString(psCurrentMenu->pszTitle,psCurrentMenu->titleSize);
  SerialPutString("\r\n                                              ",48);
  SerialPutString("\r\n==============================================",48);
  SerialPutString("\r\n                                              ",48);
  for (i=0; i<psCurrentMenu->nItems; i++)
  {
    SerialPutString("\r\n",2);
    Int2Str(IntegerStr, i);
    SerialPutString(IntegerStr,i/10 + 1);
    SerialPutString(" -- ",4);
    SerialPutString((psCurrentMenu->psItems[i]).pszTitle,(psCurrentMenu->psItems[i]).titleSize);
  }
  if(nMenuLevel)
  {
  SerialPutString("\r\n                                              ",48);
  SerialPutString("\r\nR or r -- Return to Previous Menu             ",48);
  }
  SerialPutString("\r\n                                              ",48);
  SerialPutString("\r\nSelect a menu item and then press Enter       ",48);
  SerialPutString("\r\n                                              ",48);
  SerialPutString("\r\n==============================================",48);
  SerialPutString("\r\n\r\n",4);

}

/*******************************************************************************
* Function Name  : SelItem
* Description    : Select one item and refresh the menu display.
* Input          : ItemNb the index of the menu item to select
* Output         : None
* Return         : None
*******************************************************************************/
void SelItem(s32 ItemNb)
{
  psCurrentMenu->psItems[ItemNb].pfMenuFunc();

  if(psCurrentMenu->psItems[ItemNb].psSubMenu!= NULL)
  {
    psPrevMenu[nMenuLevel] = psCurrentMenu ;
    nMenuLevel++;
    psCurrentMenu = (psCurrentMenu->psItems[ItemNb]).psSubMenu; 
  }
  DisplayMenu();
}

/*******************************************************************************
* Function Name  : ReturnPreviousMenu
* Description    : go back to the upper level menu and refresh the menu display.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void ReturnPreviousMenu(void)
{
  if(nMenuLevel)
  {  
    nMenuLevel--;
    psCurrentMenu = psPrevMenu[nMenuLevel];
  }
  DisplayMenu();
}

/*******************************************************************************
* Function Name  : ManageMenu
* Description    : this function manages the menu.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void ManageMenu(void)
{
  s32 KeyInput;
  
  KeyInput = GetMenuInput(psCurrentMenu->nItems);
  if(KeyInput>=0)
  {
    SelItem(KeyInput);
  }
  else
  {
    ReturnPreviousMenu();
  }
}


/*******************************************************************************
* Function Name  : IdleFunc
* Description    : Idle function.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void IdleFunc(void)
{
  /* Nothing to execute: return */
  return;
}

/*******************************************************************************
* Function Name  : NotImplementedFunc
* Description    : Display a not implemented message.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void NotImplementedFunc(void)
{
  /* Display Message */
 SerialPutString("\r\nFunction not implemented press any key        ",48);
 SerialPutString("\r\n                                              ",48);
 // wait for 1 key to be pressed
 GetKey();


  return;
}

/******************* (C) COPYRIGHT 2007 STMicroelectronics *****END OF FILE****/
