/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : main.c
* Author             : MCD Application Team
* Version            : V1.0
* Date               : 12/28/2007
* Description        : Power mode selection file
********************************************************************************
* History:
* 12/28/2007 : Version 1.0
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x_lib.h"
#include "power.h"

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* External variables --------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Extern function prototypes ------------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/*******************************************************************************
* Function Name  : Enter_xxx
* Description    : Functions that enter a specific power mode.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void Enter_HSE_PLL72 (void)
{
      GPIO_InitTypeDef GPIO_InitStructure;
    u32 i;

  /* Enable HSE */
  RCC_HSEConfig(RCC_HSE_ON);

  /* Wait till HSE is ready */
  while(RCC_GetFlagStatus(RCC_FLAG_HSERDY) == RESET)
  {
  }

  /* Configure System clock */
  /* Disable PLL */ 
  RCC_PLLCmd(DISABLE);

  FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);
  /* Flash 2 wait state */
  FLASH_SetLatency(FLASH_Latency_2);

  /* HCLK = SYSCLK */
  RCC_HCLKConfig(RCC_SYSCLK_Div1); 
  RCC_PCLK2Config(RCC_HCLK_Div2); 			
  RCC_PCLK1Config(RCC_HCLK_Div4);

  /* PLLCLK = 8MHz * 9 = 72 MHz */
  RCC_PLLConfig(RCC_PLLSource_HSE_Div1, RCC_PLLMul_9);

  /* Enable PLL */ 
  RCC_PLLCmd(ENABLE);

  /* Wait till PLL is ready */
  while(RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET)
  {
  }

/* Switch system clock to PLL *************************************************/ 
  /* Select PLL as system clock source */
  RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);

  /* Wait till PLL is used as system clock source */
  while(RCC_GetSYSCLKSource() != 0x08)
  {
  }
  
  // enable all the peripheral clocks
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_ALL, ENABLE);
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_ALL, ENABLE);

  /* LED configuration */
  /* Configure PC.07 as output push-pull */
  GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_6;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOC, &GPIO_InitStructure);

  while(1)
  {
      for (i=0; i<0xffff;i++);
        GPIO_SetBits(GPIOC, GPIO_Pin_6);
      for (i=0; i<0xffff;i++);
        GPIO_ResetBits(GPIOC, GPIO_Pin_6);

  };
}

void Enter_HSI_8(void)
{
    GPIO_InitTypeDef GPIO_InitStructure;
    u32 i;
  /* HCLK = SYSCLK */
  RCC_HCLKConfig(RCC_SYSCLK_Div1); 
  RCC_PCLK2Config(RCC_HCLK_Div2); 			
  RCC_PCLK1Config(RCC_HCLK_Div4);

  /* Select HSI as system clock source */
  RCC_SYSCLKConfig(RCC_SYSCLKSource_HSI);

  /* Wait till HSI is used as system clock source */
  while(RCC_GetSYSCLKSource() != 0x00)
  {
  }

  FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);  
  FLASH_SetLatency(FLASH_Latency_0);

  // enable all the peripheral clocks
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_ALL, ENABLE);
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_ALL, ENABLE);

  /* LED configuration */
  /* Configure PC.07 as output push-pull */
  GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_6;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOC, &GPIO_InitStructure);

  while(1)
  {
      for (i=0; i<0xffff;i++);
        GPIO_SetBits(GPIOC, GPIO_Pin_6);
      for (i=0; i<0xffff;i++);
        GPIO_ResetBits(GPIOC, GPIO_Pin_6);
  };
}

void Enter_Sleep_Peripherals(void)
{
    GPIO_InitTypeDef GPIO_InitStructure;
    u32 i;


  /* HCLK = SYSCLK */
  RCC_HCLKConfig(RCC_SYSCLK_Div1); 
  RCC_PCLK2Config(RCC_HCLK_Div2); 			
  RCC_PCLK1Config(RCC_HCLK_Div4);

  /* Select HSI as system clock source */
  RCC_SYSCLKConfig(RCC_SYSCLKSource_HSI);

  /* Wait till HSI is used as system clock source */
  while(RCC_GetSYSCLKSource() != 0x00)
  {
  }

  FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);  
  FLASH_SetLatency(FLASH_Latency_0);

  // enable all the peripheral clocks
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_ALL, ENABLE);
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_ALL, ENABLE);

  // enter wait for interrupt state
  __WFI();

  /* LED configuration */
  /* Configure PC.07 as output push-pull */
  GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_6;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOC, &GPIO_InitStructure);

  while(1)
  {
      for (i=0; i<0xffff;i++);
        GPIO_SetBits(GPIOC, GPIO_Pin_6);
      for (i=0; i<0xffff;i++);
        GPIO_ResetBits(GPIOC, GPIO_Pin_6);

  };
}

void Enter_Sleep_without_Peripherals(void)
{
    GPIO_InitTypeDef GPIO_InitStructure;
    u32 i;


  /* HCLK = SYSCLK */
  RCC_HCLKConfig(RCC_SYSCLK_Div1); 
  RCC_PCLK2Config(RCC_HCLK_Div2); 			
  RCC_PCLK1Config(RCC_HCLK_Div4);

  /* Select HSI as system clock source */
  RCC_SYSCLKConfig(RCC_SYSCLKSource_HSI);

  /* Wait till HSI is used as system clock source */
  while(RCC_GetSYSCLKSource() != 0x00)
  {
  }

  FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);  
  FLASH_SetLatency(FLASH_Latency_0);

  // disable all the peripheral clocks
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_ALL, DISABLE);
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_ALL, DISABLE);
  // enter wait for interrupt state
  __WFI();

  /* LED configuration */
  /* Configure PC.07 as output push-pull */
  GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_6;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOC, &GPIO_InitStructure);

  while(1)
  {
      for (i=0; i<0xffff;i++);
        GPIO_SetBits(GPIOC, GPIO_Pin_6);
      for (i=0; i<0xffff;i++);
        GPIO_ResetBits(GPIOC, GPIO_Pin_6);

  };
}

void Enter_Stop_Normal(void)
{
    GPIO_InitTypeDef GPIO_InitStructure;
    u32 i;

    
  /* HCLK = SYSCLK */
  RCC_HCLKConfig(RCC_SYSCLK_Div1); 
  RCC_PCLK2Config(RCC_HCLK_Div2); 			
  RCC_PCLK1Config(RCC_HCLK_Div4);

  /* Select HSI as system clock source */
  RCC_SYSCLKConfig(RCC_SYSCLKSource_HSI);

  /* Wait till HSI is used as system clock source */
  while(RCC_GetSYSCLKSource() != 0x00)
  {
  }

  FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);  
  FLASH_SetLatency(FLASH_Latency_0);

  /* Request to enter STOP mode with regulator ON */
  PWR_EnterSTOPMode(PWR_Regulator_ON, PWR_STOPEntry_WFE);

  /* LED configuration */
  /* Configure PC.07 as output push-pull */
  GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_6;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOC, &GPIO_InitStructure);

  while(1)
  {
      for (i=0; i<0xffff;i++);
        GPIO_SetBits(GPIOC, GPIO_Pin_6);
      for (i=0; i<0xffff;i++);
        GPIO_ResetBits(GPIOC, GPIO_Pin_6);

  };
}

void Enter_Stop_LowPower(void)
{
    GPIO_InitTypeDef GPIO_InitStructure;
    u32 i;


  /* HCLK = SYSCLK */
  RCC_HCLKConfig(RCC_SYSCLK_Div1); 
  RCC_PCLK2Config(RCC_HCLK_Div2); 			
  RCC_PCLK1Config(RCC_HCLK_Div4);

  /* Select HSI as system clock source */
  RCC_SYSCLKConfig(RCC_SYSCLKSource_HSI);

  /* Wait till HSI is used as system clock source */
  while(RCC_GetSYSCLKSource() != 0x00)
  {
  }

  FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);  
  FLASH_SetLatency(FLASH_Latency_0);

  /* Request to enter STOP mode with regulator in Low Power */
  PWR_EnterSTOPMode(PWR_Regulator_LowPower, PWR_STOPEntry_WFE);


  /* LED configuration */
  /* Configure PC.07 as output push-pull */
  GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_6;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOC, &GPIO_InitStructure);

  while(1)
  {
      for (i=0; i<0xffff;i++);
        GPIO_SetBits(GPIOC, GPIO_Pin_6);
      for (i=0; i<0xffff;i++);
        GPIO_ResetBits(GPIOC, GPIO_Pin_6);

  };
}

void Enter_Standby_RTC(void)
{
    GPIO_InitTypeDef GPIO_InitStructure;
    u32 i;


  /* HCLK = SYSCLK */
  RCC_HCLKConfig(RCC_SYSCLK_Div1); 
  RCC_PCLK2Config(RCC_HCLK_Div2); 			
  RCC_PCLK1Config(RCC_HCLK_Div4);

  /* Select HSI as system clock source */
  RCC_SYSCLKConfig(RCC_SYSCLKSource_HSI);

  /* Wait till HSI is used as system clock source */
  while(RCC_GetSYSCLKSource() != 0x00)
  {
  }

  FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);  
  FLASH_SetLatency(FLASH_Latency_0);

  /* Check if the StandBy flag is set */
  if(PWR_GetFlagStatus(PWR_FLAG_SB) != RESET)
  {/* System resumed from STANDBY mode */

    /* Clear StandBy flag */
    PWR_ClearFlag(PWR_FLAG_SB);

    /* Wait for RTC APB registers synchronisation */
    RTC_WaitForSynchro();
    /* No need to configure the RTC as the RTC configuration(clock source, enable,
       prescaler,...) is kept after wake-up from STANDBY */
	
  }
  else
  {/* StandBy flag is not set */

    /* RTC clock source configuration ----------------------------------------*/
    BKP_DeInit();
  
    /* Enable LSE OSC */
    RCC_LSEConfig(RCC_LSE_ON);
    /* Wait till LSE is ready */
    while(RCC_GetFlagStatus(RCC_FLAG_LSERDY) == RESET)
    {
    }

    /* Select the RTC Clock Source */
    RCC_RTCCLKConfig(RCC_RTCCLKSource_LSE);

    /* Enable the RTC Clock */
    RCC_RTCCLKCmd(ENABLE);

    /* RTC configuration -----------------------------------------------------*/
    /* Wait for RTC APB registers synchronisation */
    RTC_WaitForSynchro();

    /* Set the RTC time base to ~61 us ( = 2/32768) */
    RTC_SetPrescaler(1);  
    /* Wait until last write operation on RTC registers has finished */
    RTC_WaitForLastTask();
  }

  /* Wait till RTC Second event occurs */
  RTC_ClearFlag(RTC_FLAG_SEC);
 
  while(RTC_GetFlagStatus(RTC_FLAG_SEC) == RESET);

  /* Wait until last write operation on RTC registers has finished */
  RTC_WaitForLastTask();

  /* Request to enter STANDBY mode (Wake Up flag is cleared in PWR_EnterSTANDBYMode function) */
  PWR_EnterSTANDBYMode();


  /* LED configuration */
  /* Configure PC.07 as output push-pull */
  GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_6;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOC, &GPIO_InitStructure);

  while(1)
  {
      for (i=0; i<0xffff;i++);
        GPIO_SetBits(GPIOC, GPIO_Pin_6);
      for (i=0; i<0xffff;i++);
        GPIO_ResetBits(GPIOC, GPIO_Pin_6);

  };
}

void Enter_Standby_NoRTC(void)
{
    GPIO_InitTypeDef GPIO_InitStructure;
    u32 i;

    
  /* HCLK = SYSCLK */
  RCC_HCLKConfig(RCC_SYSCLK_Div1); 
  RCC_PCLK2Config(RCC_HCLK_Div2); 			
  RCC_PCLK1Config(RCC_HCLK_Div4);

  /* Select HSI as system clock source */
  RCC_SYSCLKConfig(RCC_SYSCLKSource_HSI);

  /* Wait till HSI is used as system clock source */
  while(RCC_GetSYSCLKSource() != 0x00)
  {
  }

  FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);  
  FLASH_SetLatency(FLASH_Latency_0);

    /* Disable the RTC Clock */
  PWR_BackupAccessCmd(DISABLE);
  PWR_WakeUpPinCmd(DISABLE);
  PWR_PVDCmd(DISABLE);
  RCC_RTCCLKCmd(DISABLE);
  RCC_BackupResetCmd(ENABLE);


  /* Request to enter STANDBY mode (Wake Up flag is cleared in PWR_EnterSTANDBYMode function) */
  PWR_EnterSTANDBYMode();


  /* LED configuration */
  /* Configure PC.07 as output push-pull */
  GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_6;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOC, &GPIO_InitStructure);

  while(1)
  {
      for (i=0; i<0xffff;i++);
        GPIO_SetBits(GPIOC, GPIO_Pin_6);
      for (i=0; i<0xffff;i++);
        GPIO_ResetBits(GPIOC, GPIO_Pin_6);

  };
}



/******************* (C) COPYRIGHT 2007 STMicroelectronics *****END OF FILE****/

